﻿using Microsoft.Win32;
using Syncfusion.UI.Xaml.Grid;
using Syncfusion.UI.Xaml.Grid.Converter;
using Syncfusion.XlsIO;
using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace SfDataGridDemo
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {       
        public MainWindow()
        {
            InitializeComponent();          
        }

        private void ExportToExcel_Click(object sender, RoutedEventArgs e)
        {
            var options = new ExcelExportingOptions();

            // Assign the customized cellsExportingHandler to ExcelExportingOptions
            options.CellsExportingEventHandler = cellsExportingHandler;
           
            //Create new workbook from excel engine
            ExcelEngine excelEngine = new ExcelEngine();
            IWorkbook workBook = excelEngine.Excel.Workbooks.Create();
            workBook.Worksheets.Create();

            //Export the grid in to excel
            this.sfDataGrid.ExportToExcel(sfDataGrid.View, options,workBook.Worksheets[0]);

            //Save the excel sheet with specified file name
            SaveFileDialog sfd = new SaveFileDialog
            {
                FilterIndex = 2,
                Filter = "Excel 97 to 2003 Files(*.xls)|*.xls|Excel 2007 to 2010 Files(*.xlsx)|*.xlsx"
            };

            if (sfd.ShowDialog() == true)
            {
                using (Stream stream = sfd.OpenFile())
                {
                    if (sfd.FilterIndex == 1)
                        workBook.Version = ExcelVersion.Excel97to2003;
                    else
                        workBook.Version = ExcelVersion.Excel2010;
                    workBook.SaveAs(stream);
                }

                //Message box confirmation to view the created spreadsheet.
                if (MessageBox.Show("Do you want to view the workbook?", "Workbook has been created",
                                    MessageBoxButton.YesNo, MessageBoxImage.Information) == MessageBoxResult.Yes)
                {
                    //Launching the Excel file using the default Application.[MS Excel Or Free ExcelViewer]
                    System.Diagnostics.Process.Start(sfd.FileName);
                }
            }        
        }
        private void cellsExportingHandler(object sender, GridCellExcelExportingEventArgs e)
        {
            // Based on the column mapping name and the cell type, we can change the cell values while exporting to excel.
            if (e.CellType == ExportCellType.RecordCell && e.ColumnName == "IsClosed")
            {
                //if the cell value is True, "Y" will be displayed else "N" will be displyed.
                if (e.CellValue.Equals(true))
                    e.Range.Cells[0].Value = "Y";
                else
                    e.Range.Cells[0].Value = "N";
                e.Handled = true;
            }
        }

        private void ExportToPDF_Click(object sender, RoutedEventArgs e)
        {
            var options = new PdfExportingOptions();

            options.FitAllColumnsInOnePage = true;
            // Assign the customized cellsExportingHandler to PdfExportingOptions
            options.CellsExportingEventHandler = cellsExportingEventHandler;

            var document = this.sfDataGrid.ExportToPdf(options);
            SaveFileDialog sfd = new SaveFileDialog
            {
                Filter = "PDF Files(*.Pdf)|*.Pdf"
            };

            if (sfd.ShowDialog() == true)
            {
                using (Stream stream = sfd.OpenFile())
                {
                    document.Save(stream);
                }
                //Message box confirmation to view the created PDF file.
                if (MessageBox.Show("Do you want to view the PDF file?", "PDF file has been created",
                      MessageBoxButton.YesNo, MessageBoxImage.Information) == MessageBoxResult.Yes)
                {

                    //Launching the PDF file using the default Application.
                    System.Diagnostics.Process.Start(sfd.FileName);
                }
            }
        }

        private void cellsExportingEventHandler(object sender, GridCellPdfExportingEventArgs e)
        {

            // Based on the column mapping name and the cell type, we can change the cell values when exporting to PDF.
            if(e.CellType==ExportCellType.RecordCell&&e.ColumnName=="IsClosed")
            {
                //if the cell value is True, "Y" will be displayed else "N" will be displyed.
                if (e.CellValue.Equals("True"))
                    e.CellValue= "Y";
                else
                    e.CellValue = "N";               
            }
        }
    }
}
